@@ -1,12 +1,9 @@
-from pulsar.mesos import (
-    ensure_mesos_libs
-)
-from pulsar.mesos.framework import run
-
 from pulsar.main import (
     ArgumentParser,
     PulsarManagerConfigBuilder,
 )
+from pulsar.mesos import ensure_mesos_libs
+from pulsar.mesos.framework import run
 
 DESCRIPTION = "Pulsar Mesos Framework Entry Point."
 
@@ -21,7 +18,7 @@ def main(argv=None):
     ensure_mesos_libs()
 
     config_builder = PulsarManagerConfigBuilder(args)
-    config_builder.setup_logging()
+    config_builder.setup_file_logging()
     config = config_builder.load()
 
     run(
